@@ -10,6 +10,7 @@ import socket
 import inspect
 import os
 import traceback
+import pathlib
 
 
 class App:
@@ -84,7 +85,8 @@ class App:
 
     def default_response(self, response):
         response.status_code = 404
-        response.body = self.custom_template("selfpages", "error-404.html")
+        # response.body = self.custom_template("selfpages", "error-404.html")
+        self.exception_handler.handle_404(response)
 
     def find_handler(self, request_path):
         for path, handler in self.routes.items():
@@ -129,10 +131,10 @@ class App:
             loader=FileSystemLoader(os.path.abspath(templates_dir)))
         self.templates_dir = templates_dir
     
-    # def create_defaults(self):
-    #     os.mkdir("apppages")
-    #     with open(f'{os.path.abspath("apppages")}/error404.html', "w") as f:
-    #         f.write("...")
+    def create_defaults(self):
+        os.mkdir("apppages")
+        with open(f'{pathlib.Path("apppages")}/error-500.html', "w") as f:
+            f.write("...")
             
 
     def run(self):
